@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014,2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -14,15 +14,20 @@
 #include "gpgproc.h"
 
 #include "kgpgsettings.h"
+#include "kgpg_debug.h"
 
-#include <KDebug>
 #include <KProcess>
-#include <KStandardDirs>
+
+#include <QDebug>
 #include <QDir>
 #include <QFileInfo>
 #include <QStringList>
 #include <QTextCodec>
 
+#ifndef Q_OS_WIN
+  #include <sys/stat.h>
+#endif
+
 class GnupgBinary {
 public:
 	GnupgBinary();
@@ -110,12 +115,12 @@ getGpgProcessHome(const QString &binary)
 
 void GnupgBinary::setBinary(const QString &executable)
 {
-	kDebug(2100) << "checking version of GnuPG executable" << executable;
+	qCDebug(KGPG_LOG_GENERAL) << "checking version of GnuPG executable" << executable;
 	// must be set first as gpgVersionString() uses GPGProc to parse the output
 	m_binary = executable;
 	const QString verstr = GPGProc::gpgVersionString(executable);
 	m_version = GPGProc::gpgVersion(verstr);
-	kDebug(2100) << "version is" << verstr << m_version;
+	qCDebug(KGPG_LOG_GENERAL) << "version is" << verstr << m_version;
 
 	m_useDebugLevel = (m_version > 0x20000);
 
@@ -161,7 +166,7 @@ bool GnupgBinary::supportsDebugLevel() const
 	return m_useDebugLevel;
 }
 
-K_GLOBAL_STATIC(GnupgBinary, lastBinary)
+Q_GLOBAL_STATIC(GnupgBinary, lastBinary)
 
 GPGProc::GPGProc(QObject *parent, const QString &binary)
        : KLineBufferedProcess(parent)
@@ -190,28 +195,18 @@ GPGProc::resetProcess(const QString &binary)
 
 	setOutputChannelMode(OnlyStdoutChannel);
 
-	disconnect(SIGNAL(finished(int,QProcess::ExitStatus)));
-	disconnect(SIGNAL(lineReadyStandardOutput()));
+	disconnect(this, static_cast<void(GPGProc::*)(int, QProcess::ExitStatus)>(&GPGProc::finished), this, &GPGProc::processExited);
+	disconnect(this, &GPGProc::lineReadyStandardOutput, this, &GPGProc::readReady);
 }
 
 void GPGProc::start()
 {
 	// make sure there is exactly one connection from us to that signal
-	connect(this, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(finished()), Qt::UniqueConnection);
-	connect(this, SIGNAL(lineReadyStandardOutput()), this, SLOT(received()), Qt::UniqueConnection);
+	connect(this, static_cast<void(GPGProc::*)(int, QProcess::ExitStatus)>(&GPGProc::finished), this, &GPGProc::processExited, Qt::UniqueConnection);
+	connect(this, &GPGProc::lineReadyStandardOutput, this, &GPGProc::readReady, Qt::UniqueConnection);
 	KProcess::start();
 }
 
-void GPGProc::received()
-{
-	emit readReady();
-}
-
-void GPGProc::finished()
-{
-	emit processExited();
-}
-
 int GPGProc::readln(QString &line, const bool colons)
 {
 	QByteArray a;
@@ -311,34 +306,23 @@ int GPGProc::gpgVersion(const QString &vstr)
 
 QString GPGProc::gpgVersionString(const QString &binary)
 {
-	GPGProc process(0, binary);
-	process << QLatin1String( "--version" );
-	process.start();
-	process.waitForFinished(-1);
+	const QStringList vlist = getGgpParsedConfig(binary, "version");
 
-	if (process.exitCode() == 255)
+	if (vlist.empty())
 		return QString();
 
-	QString line;
-	if (process.readln(line) != -1)
-		return line.simplified().section(QLatin1Char( ' ' ), -1);
-	else
-		return QString();
+	return vlist.first().split(QLatin1Char(':')).first();
 }
 
 QStringList
 GPGProc::getGpgPubkeyAlgorithms(const QString &binary)
 {
-	QStringList ret;
+	QStringList ret = getGgpParsedConfig(binary, "pubkeyname");
 
-	foreach (const QString &s, getGpgStatusLine(binary, QLatin1String("Pubkey:")).split(QLatin1Char(','))) {
-		QString t = s.trimmed();
-		if (t == QLatin1String("?"))
-			continue;
-		ret << t;
-	}
+	if (ret.isEmpty())
+		return ret;
 
-	return ret;
+	return ret.first().split(QLatin1Char(':')).first().split(QLatin1Char(';'));
 }
 
 QString GPGProc::getGpgStartupError(const QString &binary)
@@ -360,6 +344,29 @@ QString GPGProc::getGpgStartupError(const QString &binary)
 	return result;
 }
 
+QStringList GPGProc::getGgpParsedConfig(const QString &binary, const QByteArray &key)
+{
+	GPGProc process(0, binary);
+	process << QLatin1String("--list-config") << QLatin1String("--with-colons");
+	process.start();
+	process.waitForFinished(-1);
+
+	QStringList result;
+	QByteArray filter = "cfg:";
+	if (!key.isEmpty())
+		filter += key + ':';
+
+	while (process.hasLineStandardOutput()) {
+		QByteArray tmp;
+		process.readLineStandardOutput(&tmp);
+
+		if (tmp.startsWith(filter))
+			result << QString::fromUtf8(tmp.mid(filter.length()));
+	}
+
+	return result;
+}
+
 QString GPGProc::getGpgHome(const QString &binary)
 {
 	// First try: if environment is set GnuPG will use that directory
@@ -375,7 +382,7 @@ QString GPGProc::getGpgHome(const QString &binary)
 
 	// Third try: guess what it is.
 	if (gpgHome.isEmpty()) {
-#ifdef Q_OS_WIN32	//krazy:exclude=cpp
+#ifdef Q_OS_WIN 	//krazy:exclude=cpp
 		gpgHome = qgetenv("APPDATA") + QLatin1String( "/gnupg/" );
 		gpgHome.replace(QLatin1Char( '\\' ), QLatin1Char( '/' ));
 #else
@@ -391,8 +398,12 @@ QString GPGProc::getGpgHome(const QString &binary)
 	if (gpgHome.startsWith(QLatin1String("~/")))
 		gpgHome.replace(0, 1, QDir::homePath());
 
-	KStandardDirs::makeDir(gpgHome, 0700);
+#ifdef Q_OS_WIN
+	QDir().mkpath(gpgHome);
+#else
+	uint mask = umask(077);
+	QDir().mkpath(gpgHome);
+	umask(mask);
+#endif
 	return gpgHome;
 }
-
-#include "gpgproc.moc"
