@@ -18,7 +18,7 @@
 
 #include "core/kgpgkey.h"
 
-#include <KUrl>
+#include <QUrl>
 #include <QObject>
 
 class QString;
@@ -35,12 +35,12 @@ public:
 	/**
 	 * @brief KGpgGenerateRevoke's constructor
 	 * @param parent parent object
-	 * @param id key fingerprint to generate revokation certificate for
+	 * @param keyID key fingerprint to generate revokation certificate for
 	 * @param revokeUrl place to store the certificate (may be empty)
 	 * @param reason revokation reason
 	 * @param description text description for revokation
 	 */
-	KGpgGenerateRevoke(QObject *parent, const QString &keyID, const KUrl &revokeUrl, const int reason, const QString &description);
+	KGpgGenerateRevoke(QObject *parent, const QString &keyID, const QUrl &revokeUrl, const int reason, const QString &description);
 	virtual ~KGpgGenerateRevoke();
 
 	/**
@@ -52,16 +52,16 @@ signals:
 	void revokeCertificate(const QString &cert);
 
 protected:
-	virtual bool preStart() Q_DECL_OVERRIDE;
-	virtual bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	virtual ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
-	virtual void finish() Q_DECL_OVERRIDE;
-	virtual bool passphraseReceived() Q_DECL_OVERRIDE;
-	virtual ts_boolanswer confirmOverwrite (KUrl &currentFile) Q_DECL_OVERRIDE;
+	bool preStart() Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
+	void finish() Q_DECL_OVERRIDE;
+	bool passphraseReceived() Q_DECL_OVERRIDE;
+	ts_boolanswer confirmOverwrite (QUrl &currentFile) Q_DECL_OVERRIDE;
 
 private:
 	QString m_keyid;
-	KUrl m_revUrl;
+	QUrl m_revUrl;
 	int m_reason;
 	QString m_description;
 	QString m_output;
